@@ -220,13 +220,12 @@ main(int argc, char **argv)
             { "promiscuous",        0, 0, 'P' },
             { "incremental",        1, 0, 'i' },
             { "threads",	    1, 0, 't' },
-            { "canonical",          0, 0, 'C' },
-            { "fast",               0, 0, 'F' },
             { "embed-id",           0, 0, 'E' },
 	    { "sizes",              0, 0, 'S' },	/* undocumented */
+	    { "noignores",          0, 0, 'N' },	/* undocumented */
 	    { NULL,                 0, 0, '\0'}, 
 	};
-	int c = getopt_long(argc, argv, "+hVw:cl:grvqaA:R:Tk:e:s:pPi:t:CFSE", options, NULL);
+	int c = getopt_long(argc, argv, "+hVw:cl:grvqaA:R:Tk:e:s:pPi:t:SEN", options, NULL);
 	if (c < 0)
 	    break;
 	switch(c) {
@@ -236,8 +235,6 @@ main(int argc, char **argv)
                    "Mandatory arguments to long options are mandatory for short options too.\n"
                    " -h --help                       This help\n"
 		   " -g --graph                      Dump the commit graph\n"
-		   " -k --expand[=MODE]              Enable keyword expansion (default b (old-value, no EOL change))\n"
-		   "                                 valid MODEs are kv, kvl, k, v, o, b\n"
                    " -V --version                    Print version\n"
                    " -w --commit-time-window=WINDOW  Time window for commits(seconds)\n"
 		   " -c --content-only               Don't trust commit-IDs\n"
@@ -328,6 +325,7 @@ main(int argc, char **argv)
 	case 'i':
 	    assert(optarg);
 	    export_options.fromtime = convert_date(optarg);
+	    noignores = true;
 	    break;
 	case 't':
 #ifdef THREADS
@@ -337,16 +335,13 @@ main(int argc, char **argv)
 	    announce("not built with thread support, -t option ignored.\n");
 #endif
 	    break;
-	case 'C':
-	    export_options.reportmode = canonical;
-	    break;
-	case 'F':
-	    export_options.reportmode = fast;
-	    break;
 	case 'S':
 	    print_sizes();
 	    // cppcheck-suppress memleak
 	    return 0;
+	case 'N':
+	    noignores = true;
+	    break;
 	default: /* error message already emitted */
 	    announce("try `%s --help' for more information.\n", argv[0]);
 	    return 1;
