@@ -12,7 +12,7 @@ DEBUG_LIFTER   = 4
 
 verbose = 0
 
-os.putenv("PATH", os.getenv("PATH") + os.pathsep + "..") 
+os.putenv("PATH", os.getenv("PATH") + os.pathsep + "..")
 
 binary_encoding = 'Latin-1'	# Preserves high bits in data
 
@@ -51,8 +51,8 @@ def capture_or_die(dcmd, legend=""):
         elif e.returncode != 0:
             sys.stderr.write("%s: child returned %d." % (caller, e.returncode))
         sys.exit(1)
-    
-class directory_context:
+
+class directory_context(object):
     def __init__(self, target):
         self.target = target
         self.source = None
@@ -65,7 +65,7 @@ class directory_context:
     def __exit__(self, extype, value_unused, traceback_unused):
         os.chdir(self.source)
 
-class RCSRepository:
+class RCSRepository(object):
     "An RCS file collection."
     def __init__(self, name):
         self.name = name
@@ -109,9 +109,9 @@ class RCSRepository:
     def checkin(self, filename, message):
         "Check in changes to the specified file."
         self.do("ci", "-m'%s' %s" % (message, filename))
-    def stream(self, module, gitdir, outfile, more_opts=''):
+    def stream(self, _module, _gitdir, outfile, more_opts=''):
         vopt = "-v " * (verbose - DEBUG_LIFTER + 1)
-        # The -L is necessary to handle proxied directories. 
+        # The -L is necessary to handle proxied directories.
         self.run_with_cleanup('find -L {0} -name "*,v" | cvs-fast-export {1} {2} >{3}'.format(self.directory, vopt, more_opts, outfile))
     def convert(self, module, gitdir, more_opts=''):
         "Convert the repo."
@@ -168,7 +168,7 @@ class CVSRepository(RCSRepository):
             for checkout in self.checkouts:
                 checkout.cleanup()
 
-class CVSCheckout:
+class CVSCheckout(object):
     PROXYSUFFIX = "-proxy"
     def __init__(self, repo, module, checkout=None):
         self.repo = repo
@@ -269,7 +269,7 @@ def expect_same(a, b):
         return
     if not filecmp.cmp(a, b, shallow=False):
         sys.stderr.write("%s and %s are not the same.\n" % (a, b))
-    
+
 def expect_different(a, b):
     "Rejoice if two files are unexpectedly identical"
     if not os.path.exists(a):
@@ -285,7 +285,7 @@ def junkbranch(name):
     "Is this a synthetic branch generated by cvs-fast-export?"
     return  name.startswith("import-") or name.find("UNNAMED") != -1
 
-class ConvertComparison:
+class ConvertComparison(object):
     "Compare a CVS repository and its conversion for equality."
     # Needs to stay synchronized with reposurgeon's generic conversion makefile
     SUFFIX = "-git"
@@ -312,9 +312,9 @@ class ConvertComparison:
                 sys.stderr.write(preamble + "%s unexpectedly missing.\n" % ref)
             return False
         def ftw(mydir, ignore):
-            for root, dirs, files in os.walk(mydir):
-                for file in files:
-                    path = os.path.join(root, file)
+            for root, _, files in os.walk(mydir):
+                for walkfile in files:
+                    path = os.path.join(root, walkfile)
                     if ignore not in path.split(os.sep) and not path.endswith(".cvsignore") and not path.endswith(".gitignore"):
                         yield path
         self.checkout.update(ref)
@@ -322,11 +322,10 @@ class ConvertComparison:
             if not noisy_run("git checkout --quiet %s" % ref):
                 self.repo.cleanup()
                 sys.exit(1)
-        if 0:
-            with directory_context(self.stem + ConvertComparison.SUFFIX):
-                if not noisy_run("git log --format=%H -1"):
-                    self.repo.cleanup()
-                    sys.exit(1)
+        # with directory_context(self.stem + ConvertComparison.SUFFIX):
+        #    if not noisy_run("git log --format=%H -1"):
+        #        self.repo.cleanup()
+        #        sys.exit(1)
         cvspaths = list(ftw(self.stem + ".checkout", ignore="CVS"))
         cvsfiles = [fn[len(self.stem+".checkout")+1:] for fn in cvspaths]
         gitpaths = list(ftw(self.stem + ConvertComparison.SUFFIX, ignore=".git"))
@@ -369,14 +368,14 @@ class ConvertComparison:
         return success
     def checkall(self):
         "Check all named references - branches and tags - expecting matches."
-        for branch in cc.branches:
+        for branch in self.branches:
             if branch.endswith("UNNAMED-BRANCH"):
                 if verbose > 0:
                     sys.stderr.write("%s: skipping %s\n" % (os.path.basename(sys.argv[0]), branch))
             else:
-                cc.compare_tree("branch", branch)
-        for tag in cc.tags:
-            cc.compare_tree("tag", tag)
+                self.compare_tree("branch", branch)
+        for tag in self.tags:
+            self.compare_tree("tag", tag)
     def command_returns(self, cmd, expected):
         seen = capture_or_die(cmd)
         succeeded = (seen.strip() == expected.strip())
